==> android-aihelp-aar-2.4.4-sources.jar: net/aihelp/common/Const.java <==
package net.aihelp.common;

import android.content.pm.ActivityInfo;

import net.aihelp.BuildConfig;
import net.aihelp.ui.listener.OnAIHelpSessionCloseCallback;
import net.aihelp.ui.listener.OnAIHelpSessionOpenCallback;
import net.aihelp.ui.listener.OnMessageCountArrivedCallback;
import net.aihelp.ui.listener.OnNetworkCheckResultCallback;
import net.aihelp.ui.listener.OnSpecificFormSubmittedCallback;
import net.aihelp.utils.LocaleUtil;

import java.util.Locale;

public class Const {

    public static final int SDK_PLATFORM = BuildConfig.SDK_PLATFORM;
    public static final String SDK_VERSION = BuildConfig.SDK_VERSION;

    public static String APP_ID = "";
    public static String APP_KEY = "";
    public static String TARGET_LAN = LocaleUtil.getFormatLanguage(Locale.getDefault().toString());
    public static String LOG_UPLOAD_PATH = "";

    public static String FAQ_FILE = "";
    public static String STORY_FILE = "";
    public static String OP_FILE = "";

    public static boolean TOGGLE_UPLOAD_VIDEO = false;
    public static boolean TOGGLE_CRM_TOKEN = false;
    public static boolean TOGGLE_OPEN_FAQ_NOTIFICATION = false;
    public static boolean TOGGLE_OPEN_UNREAD_MSG = false;
    public static boolean TOGGLE_UPLOAD_LOG = false;
    public static boolean TOGGLE_NET_CHECK = false;
    public static boolean TOGGLE_LOCALIZE_VIA_INIT = false;

    public static boolean TOGGLE_SHOW_NICKNAME = false;
    public static boolean TOGGLE_SHOW_PORTRAIT = false;
    public static boolean TOGGLE_GET_LAST_CONVERSATION = false;
    public static boolean TOGGLE_EVALUATE_BOT_FAQ = true;
    public static boolean TOGGLE_EVALUATE_DETAIL_FAQ = true;
    public static boolean TOGGLE_CHAT_TIMESTAMP = true;
    public static boolean TOGGLE_FETCH_MESSAGE = true;

    public static boolean PRIVACY_POLICY_ACCEPTED = true;
    public static String PRIVACY_CONTROL_DATA = "";

    public static String APP_SHOW_NAME = "";
    public static String DASHBOARD_WELCOME_MSG = "";
    public static String CUSTOM_WELCOME_MSG = "";
    public static String CUSTOM_STORY_NODE = "";

    public static String PUSH_INFO = "";

    public static int LIMIT_CHECKING_UNREAD = 0;
    public static int LIMIT_UPLOADING_VIDEO = 31457280;

    public static String NET_CHECK_HOST = "";
    public static String NET_TRACE_ROUTE = "";
    public static String NET_PING = "";
    public static OnNetworkCheckResultCallback sCheckResultListener;

    public static boolean IS_SDK_SHOWING = false;
    public static boolean isNestedFragmentOnResume = false;
    public static boolean isRunAccelerationForChina = false;
    public static boolean isLocalWelcomeAvailable = false;

    public static OnMessageCountArrivedCallback sMessageListener;
    public static OnSpecificFormSubmittedCallback sSpecificFormSubmittedListener;
    public static OnAIHelpSessionOpenCallback sSessionOpenListener;
    public static OnAIHelpSessionCloseCallback sSessionCloseListener;

}

==> android-aihelp-aar-3.1.7-sources.jar: net/aihelp/common/Const.java <==
package net.aihelp.common;

import net.aihelp.config.enums.PublishCountryOrRegion;
import net.aihelp.ui.listener.OnAIHelpSessionCloseCallback;
import net.aihelp.ui.listener.OnAIHelpSessionOpenCallback;
import net.aihelp.ui.listener.OnSpecificUrlClickedCallback;
import net.aihelp.ui.listener.OnMessageCountArrivedCallback;
import net.aihelp.ui.listener.OnNetworkCheckResultCallback;
import net.aihelp.ui.listener.OnOperationUnreadChangedCallback;
import net.aihelp.ui.listener.OnSpecificFormSubmittedCallback;
import net.aihelp.utils.LocaleUtil;

import java.util.Locale;
import java.util.Map;

public class Const {

    public static String APP_ID = "";
    public static String APP_KEY = "";
    public static String ORIGINAL_LANGUAGE = LocaleUtil.getFormatLanguage(Locale.getDefault().toString());
    public static String CORRECT_LANGUAGE = ORIGINAL_LANGUAGE;
    public static String LOG_UPLOAD_PATH = "";

    public static String FAQ_FILE = "";
    public static String STORY_FILE = "";
    public static String OP_FILE = "";

    public static boolean TOGGLE_UPLOAD_VIDEO = false;
    public static boolean TOGGLE_CRM_TOKEN = false;
    public static boolean TOGGLE_OPEN_FAQ_NOTIFICATION = false;
    public static boolean TOGGLE_OPEN_UNREAD_MSG = false;
    public static boolean TOGGLE_UPLOAD_LOG = false;
    public static boolean TOGGLE_NET_CHECK = false;
    public static boolean TOGGLE_LOCALIZE_VIA_INIT = false;
    public static boolean TOGGLE_TRANSLATE_CS_MESSAGE = false;
    public static boolean TOGGLE_MQTT_TLS = false;
    public static boolean TOGGLE_SHEET_DIALOG_ENABLE_INTERACTION = false;

    public static boolean TOGGLE_FETCH_MESSAGE = true;

    public static boolean PRIVACY_POLICY_ACCEPTED = true;

    public static String APP_SHOW_NAME = "";
    public static String DASHBOARD_WELCOME_MSG = "";
    public static String CUSTOM_WELCOME_MSG = "";
    public static String CUSTOM_STORY_NODE = "";

    public static String PUSH_INFO = "";

    public static int LIMIT_CHECKING_UNREAD = 0;
    public static int LIMIT_UPLOADING_VIDEO = 31457280;

    public static String NET_CHECK_HOST = "";
    public static String NET_TRACE_ROUTE = "";
    public static String NET_PING = "";
    public static OnNetworkCheckResultCallback sCheckResultListener;

    public static boolean IS_SDK_SHOWING = false;
    public static boolean isNestedFragmentOnResume = false;
    public static boolean isLocalWelcomeAvailable = false;
    public static boolean isOperateFileHasUpdates = false;

    public static Map<String, Object> sActivityInfo;
    public static PublishCountryOrRegion countryOrRegion = null;

    public static OnMessageCountArrivedCallback sMessageListener;
    public static OnSpecificFormSubmittedCallback sSpecificFormSubmittedListener;
    public static OnAIHelpSessionOpenCallback sSessionOpenListener;
    public static OnAIHelpSessionCloseCallback sSessionCloseListener;
    public static OnOperationUnreadChangedCallback sOperationUnreadListener;
    public static OnSpecificUrlClickedCallback sOnSpecificUrlClickedListener;

}
